@@ -16,7 +16,9 @@ export function removeLeakedResources(leakedResources: Set<string>) {
       .map((r) => JSON.parse(r) as { name: string; namespace: string; kind: string })
       .forEach(({ name, namespace, kind }) => {
         try {
-          execSync(`kubectl delete -n ${namespace} --cascade ${kind} ${name}`);
+          execSync(
+            `kubectl delete --ignore-not-found=true -n ${namespace} --cascade ${kind} ${name}`,
+          );
         } catch (error) {
           console.error(`Failed to delete ${kind} ${name}:\n${error}`);
         }
@@ -53,15 +55,21 @@ export function createResources(resources) {
   resources.forEach(createResource);
 }
 
-export function deleteResource(resource) {
+export function applyResource(resource) {
+  execSync(`echo '${JSON.stringify(resource)}' | kubectl apply -f -`);
+}
+
+export function deleteResource(resource, ignoreNotFound = true) {
   const kind = resource.kind === 'NetworkAttachmentDefinition' ? 'net-attach-def' : resource.kind;
   execSync(
-    `kubectl delete -n ${resource.metadata.namespace} --cascade ${kind} ${resource.metadata.name}`,
+    `kubectl delete --ignore-not-found=${ignoreNotFound} -n ${resource.metadata.namespace} --cascade ${kind} ${resource.metadata.name}`,
   );
 }
 
-export function deleteResources(resources) {
-  resources.forEach(deleteResource);
+export function deleteResources(resources, ignoreNotFound = true) {
+  resources.forEach((resource) => {
+    deleteResource(resource, ignoreNotFound);
+  });
 }
 
 export async function withResource(
@@ -78,9 +86,32 @@ export async function withResource(
   }
 }
 
+export async function withResources(
+  resourceSet: Set<string>,
+  resources: any,
+  callback: Function,
+  keepResource: boolean = false,
+) {
+  resources.forEach((resource) => {
+    addLeakableResource(resourceSet, resource);
+  });
+  await callback();
+  if (!keepResource) {
+    resources.forEach((resource) => {
+      deleteResource(resource);
+      removeLeakableResource(resourceSet, resource);
+    });
+  }
+}
+
 export async function click(elem: any, timeout?: number) {
   const _timeout = resolveTimeout(timeout, config.jasmineNodeOpts.defaultTimeoutInterval);
   await browser.wait(until.elementToBeClickable(elem), _timeout);
+  await browser
+    .actions()
+    .mouseMove(elem)
+    .perform();
+  await browser.executeScript('arguments[0].scrollIntoView()', elem);
   await elem.click();
 }
 
@@ -149,6 +180,9 @@ export const waitForCount = (elementArrayFinder: any, targetCount: number) => {
 
 export const waitForStringInElement = (elem: any, needle: string) => {
   return async () => {
+    if (!(await elem.isPresent())) {
+      return false;
+    }
     const content = await elem.getText();
     return content.includes(needle);
   };
@@ -156,6 +190,9 @@ export const waitForStringInElement = (elem: any, needle: string) => {
 
 export const waitForStringNotInElement = (elem: any, needle: string) => {
   return async () => {
+    if (!(await elem.isPresent())) {
+      return false;
+    }
     const content = await elem.getText();
     return !content.includes(needle);
   };
