@@ -1,4 +1,5 @@
 import * as _ from 'lodash';
+import { TFunction } from 'i18next';
 import {
   ImageStreamModel,
   BuildConfigModel,
@@ -15,6 +16,14 @@ import { getKnativeServiceDepResource } from '@console/knative-plugin/src/utils/
 import { SecretType } from '@console/internal/components/secrets/create-secret';
 import { history } from '@console/internal/components/utils';
 import { getRandomChars } from '@console/shared/src/utils';
+import {
+  createPipelineForImportFlow,
+  createPipelineRunForImportFlow,
+  updatePipelineForImportFlow,
+} from '@console/pipelines-plugin/src/components/import/pipeline/pipeline-template-utils';
+import { Perspective } from '@console/plugin-sdk';
+import { setPipelineNotStarted } from '@console/pipelines-plugin/src/components/pipelines/pipeline-overview/pipeline-overview-utils';
+import { Pipeline } from '@console/pipelines-plugin/src/utils/pipeline-augment';
 import {
   getAppLabels,
   getPodLabels,
@@ -33,9 +42,8 @@ import {
   GitTypes,
   GitReadableTypes,
   Resources,
+  DevfileSuggestedResources,
 } from './import-types';
-import { createPipelineForImportFlow } from './pipeline/pipeline-template-utils';
-import { Perspective } from '@console/plugin-sdk';
 
 export const generateSecret = () => {
   // http://stackoverflow.com/questions/105034/create-guid-uuid-in-javascript
@@ -147,7 +155,15 @@ export const createOrUpdateBuildConfig = (
   const defaultAnnotations = { ...getGitAnnotations(repository, ref), ...getCommonAnnotations() };
   let buildStrategyData;
 
+  let desiredContextDir = contextDir;
+
   switch (buildStrategy) {
+    case 'Devfile':
+      buildStrategyData = originalBuildConfig?.spec?.strategy || {
+        dockerStrategy: { env, dockerfilePath },
+      };
+      desiredContextDir = originalBuildConfig?.spec?.source?.contextDir || contextDir;
+      break;
     case 'Docker':
       buildStrategyData = {
         dockerStrategy: { env, dockerfilePath },
@@ -191,7 +207,7 @@ export const createOrUpdateBuildConfig = (
         },
       },
       source: {
-        contextDir,
+        contextDir: desiredContextDir,
         git: {
           uri: repository,
           ref,
@@ -249,12 +265,11 @@ export const createOrUpdateDeployment = (
 
   const imageStreamName = imageStream && imageStream.metadata.name;
   const defaultLabels = getAppLabels({ name, applicationName, imageStreamName, selectedTag });
-  const imageName = name;
   const annotations = {
     ...getGitAnnotations(repository, ref),
     ...getCommonAnnotations(),
     'alpha.image.policy.openshift.io/resolve-names': '*',
-    ...getTriggerAnnotation(name, imageName, namespace, imageChange),
+    ...getTriggerAnnotation(name, namespace, imageChange),
   };
   const podLabels = getPodLabels(name);
   const templateLabels = getTemplateLabels(originalDeployment);
@@ -404,7 +419,130 @@ export const createOrUpdateDeploymentConfig = (
     : k8sCreate(DeploymentConfigModel, deploymentConfig, dryRun ? dryRunOpt : {});
 };
 
+export const managePipelineResources = async (
+  formData: GitImportFormData,
+  appResources: AppResources,
+) => {
+  const { name, git, pipeline, project, docker } = formData;
+  let managedPipeline: Pipeline;
+
+  if (!_.isEmpty(appResources?.pipeline?.data)) {
+    managedPipeline = await updatePipelineForImportFlow(
+      appResources?.pipeline?.data,
+      pipeline.template,
+      name,
+      project.name,
+      git.url,
+      git.ref,
+      git.dir,
+      docker.dockerfilePath,
+    );
+  } else if (pipeline.template) {
+    managedPipeline = await createPipelineForImportFlow(
+      name,
+      project.name,
+      git.url,
+      git.ref,
+      git.dir,
+      pipeline,
+      docker.dockerfilePath,
+    );
+  }
+
+  if (_.has(managedPipeline?.metadata?.labels, 'app.kubernetes.io/instance')) {
+    try {
+      await createPipelineRunForImportFlow(managedPipeline);
+    } catch (error) {
+      // eslint-disable-next-line no-console
+      console.log(error);
+      setPipelineNotStarted(managedPipeline.metadata.name, managedPipeline.metadata.namespace);
+    }
+  }
+};
+
+export const createDevfileResources = async (
+  formData: GitImportFormData,
+  dryRun: boolean,
+  appResources: AppResources,
+  generatedImageStreamName: string = '',
+): Promise<K8sResourceKind[]> => {
+  const verb: K8sVerb = 'create';
+
+  const {
+    name,
+    project: { name: namespace },
+    devfile: { devfileSuggestedResources },
+  } = formData;
+
+  const devfileResourceObjects: DevfileSuggestedResources = Object.keys(
+    devfileSuggestedResources,
+  ).reduce((acc: DevfileSuggestedResources, resourceType: string) => {
+    const resource: K8sResourceKind = devfileSuggestedResources[resourceType];
+    return {
+      ...acc,
+      [resourceType]: {
+        ...resource,
+        metadata: {
+          ...resource.metadata,
+          annotations: {
+            ...resource.metadata?.annotations,
+            isFromDevfile: 'true',
+          },
+          name,
+          namespace,
+          labels: {
+            ...resource.metadata?.labels,
+          },
+        },
+      },
+    };
+  }, {} as DevfileSuggestedResources);
+
+  return Promise.all([
+    createOrUpdateImageStream(
+      formData,
+      devfileResourceObjects.imageStream,
+      dryRun,
+      appResources,
+      verb,
+      generatedImageStreamName,
+    ),
+
+    createOrUpdateBuildConfig(
+      formData,
+      devfileResourceObjects.imageStream,
+      dryRun,
+      devfileResourceObjects.buildResource,
+      verb,
+      generatedImageStreamName,
+    ),
+
+    createWebhookSecret(formData, 'generic', dryRun),
+
+    createOrUpdateDeployment(
+      formData,
+      devfileResourceObjects.imageStream,
+      dryRun,
+      devfileResourceObjects.deployResource,
+      verb,
+    ),
+
+    k8sCreate(
+      ServiceModel,
+      createService(formData, devfileResourceObjects.imageStream, devfileResourceObjects.service),
+      dryRun ? dryRunOpt : {},
+    ),
+
+    k8sCreate(
+      RouteModel,
+      createRoute(formData, devfileResourceObjects.imageStream, devfileResourceObjects.route),
+      dryRun ? dryRunOpt : {},
+    ),
+  ]);
+};
+
 export const createOrUpdateResources = async (
+  t: TFunction,
   formData: GitImportFormData,
   imageStream: K8sResourceKind,
   createNewProject?: boolean,
@@ -432,7 +570,7 @@ export const createOrUpdateResources = async (
 
   createNewProject && (await createProject(formData.project));
 
-  const responses: K8sResourceKind[] = [];
+  const requests: Promise<K8sResourceKind>[] = [];
   let generatedImageStreamName: string = '';
   const imageStreamList = appResources?.imageStream?.data;
   if (
@@ -443,46 +581,55 @@ export const createOrUpdateResources = async (
   ) {
     generatedImageStreamName = `${name}-${getRandomChars()}`;
   }
-  const imageStreamResponse = await createOrUpdateImageStream(
-    formData,
-    imageStream,
-    dryRun,
-    appResources,
-    generatedImageStreamName ? 'create' : verb,
-    generatedImageStreamName,
-  );
-  responses.push(imageStreamResponse);
-  responses.push(
-    await createOrUpdateBuildConfig(
+
+  if (buildStrategy === 'Devfile') {
+    if (verb !== 'create') {
+      throw new Error(t('devconsole~Cannot update Devfile resources'));
+    }
+    return createDevfileResources(formData, dryRun, appResources, generatedImageStreamName);
+  }
+
+  requests.push(
+    createOrUpdateImageStream(
       formData,
       imageStream,
       dryRun,
-      _.get(appResources, 'buildConfig.data'),
-      verb,
+      appResources,
+      generatedImageStreamName ? 'create' : verb,
       generatedImageStreamName,
     ),
   );
-
-  if (verb === 'create') {
-    responses.push(await createWebhookSecret(formData, 'generic', dryRun));
+  if (pipeline.enabled) {
+    if (!dryRun) {
+      await managePipelineResources(formData, appResources);
+    }
+  } else {
+    requests.push(
+      createOrUpdateBuildConfig(
+        formData,
+        imageStream,
+        dryRun,
+        appResources?.buildConfig?.data,
+        verb,
+        generatedImageStreamName,
+      ),
+    );
   }
 
+  verb === 'create' && requests.push(createWebhookSecret(formData, 'generic', dryRun));
+
   const defaultAnnotations = getGitAnnotations(repository, ref);
 
-  if (pipeline.enabled && pipeline.template && !dryRun) {
-    responses.push(await createPipelineForImportFlow(formData));
-  }
-
   if (formData.resources === Resources.KnativeService) {
     // knative service doesn't have dry run capability so returning the promises.
     if (dryRun) {
-      return responses;
+      return Promise.all(requests);
     }
+    const [imageStreamResponse] = await Promise.all(requests);
     const imageStreamURL = imageStreamResponse.status.dockerImageRepository;
 
     const originalAnnotations = appResources?.editAppResource?.data?.metadata?.annotations || {};
     const triggerAnnotations = getTriggerAnnotation(
-      name,
       generatedImageStreamName || name,
       namespace,
       imageChange,
@@ -509,8 +656,8 @@ export const createOrUpdateResources = async (
   }
 
   if (formData.resources === Resources.Kubernetes) {
-    responses.push(
-      await createOrUpdateDeployment(
+    requests.push(
+      createOrUpdateDeployment(
         formData,
         imageStream,
         dryRun,
@@ -519,8 +666,8 @@ export const createOrUpdateResources = async (
       ),
     );
   } else if (formData.resources === Resources.OpenShift) {
-    responses.push(
-      await createOrUpdateDeploymentConfig(
+    requests.push(
+      createOrUpdateDeploymentConfig(
         formData,
         imageStream,
         dryRun,
@@ -533,27 +680,27 @@ export const createOrUpdateResources = async (
   if (!_.isEmpty(ports) || buildStrategy === 'Docker' || buildStrategy === 'Source') {
     const originalService = _.get(appResources, 'service.data');
     const service = createService(formData, imageStream, originalService);
-
-    if (verb === 'create') {
-      responses.push(await k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {}));
-    } else if (verb === 'update' && !_.isEmpty(originalService)) {
-      responses.push(await k8sUpdate(ServiceModel, service));
-    }
-
+    const request =
+      verb === 'update'
+        ? !_.isEmpty(originalService)
+          ? k8sUpdate(ServiceModel, service)
+          : null
+        : k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {});
+    requests.push(request);
     const originalRoute = _.get(appResources, 'route.data');
     const route = createRoute(formData, imageStream, originalRoute);
     if (verb === 'update' && disable) {
-      responses.push(await k8sUpdate(RouteModel, route, namespace, name));
+      requests.push(k8sUpdate(RouteModel, route, namespace, name));
     } else if (canCreateRoute) {
-      responses.push(await k8sCreate(RouteModel, route, dryRun ? dryRunOpt : {}));
+      requests.push(k8sCreate(RouteModel, route, dryRun ? dryRunOpt : {}));
     }
   }
 
   if (webhookTrigger && verb === 'create') {
-    responses.push(await createWebhookSecret(formData, gitType, dryRun));
+    requests.push(createWebhookSecret(formData, gitType, dryRun));
   }
 
-  return responses;
+  return Promise.all(requests);
 };
 
 export const handleRedirect = (
