@@ -1,7 +1,6 @@
 import * as _ from 'lodash';
 import { K8sResourceKind } from '@console/internal/module/k8s';
 import { TRIGGERS_ANNOTATION } from '@console/shared';
-import { UNASSIGNED_LABEL } from '../const';
 
 export const getAppLabels = ({
   name,
@@ -31,11 +30,7 @@ export const getAppLabels = ({
   if (runtimeIcon) {
     labels['app.openshift.io/runtime'] = runtimeIcon;
   }
-  if (
-    applicationName &&
-    applicationName !== UNASSIGNED_LABEL &&
-    applicationName.trim().length > 0
-  ) {
+  if (applicationName && applicationName.trim().length > 0) {
     labels['app.kubernetes.io/part-of'] = applicationName;
   }
   if (selectedTag) {
@@ -49,10 +44,9 @@ export const getAppLabels = ({
 };
 
 export const getGitAnnotations = (gitURL: string, gitRef?: string) => {
-  const ref = gitRef || 'master';
   return {
     'app.openshift.io/vcs-uri': gitURL,
-    'app.openshift.io/vcs-ref': ref,
+    'app.openshift.io/vcs-ref': gitRef || '',
   };
 };
 
@@ -85,10 +79,19 @@ export const getPodLabels = (name: string) => {
 };
 
 export const mergeData = (originalResource: K8sResourceKind, newResource: K8sResourceKind) => {
+  if (_.isEmpty(originalResource)) return newResource;
+
   const mergedData = _.merge({}, originalResource || {}, newResource);
-  mergedData.metadata.labels = newResource.metadata.labels;
+  const isDevfileResource = originalResource?.metadata?.annotations?.isFromDevfile;
+  mergedData.metadata.labels = {
+    ...newResource.metadata.labels,
+    ...(isDevfileResource ? originalResource?.metadata?.labels : {}),
+  };
   if (mergedData.metadata.annotations) {
-    mergedData.metadata.annotations = newResource.metadata.annotations;
+    mergedData.metadata.annotations = {
+      ...newResource.metadata.annotations,
+      ...(isDevfileResource ? originalResource?.metadata?.annotations : {}),
+    };
   }
   if (mergedData.spec?.template?.metadata?.labels) {
     mergedData.spec.template.metadata.labels = newResource.spec?.template?.metadata?.labels;
@@ -97,11 +100,16 @@ export const mergeData = (originalResource: K8sResourceKind, newResource: K8sRes
     mergedData.spec.template.spec.containers = newResource.spec.template.spec.containers;
   }
   if (mergedData?.spec?.hasOwnProperty('strategy')) {
-    mergedData.spec.strategy = newResource.spec?.strategy ?? originalResource?.spec?.strategy;
+    mergedData.spec.strategy = newResource.spec?.strategy ?? originalResource.spec?.strategy;
   }
   if (mergedData.spec?.triggers) {
     mergedData.spec.triggers = newResource.spec.triggers;
   }
+  if (mergedData.spec?.template?.spec?.hasOwnProperty('volumes')) {
+    mergedData.spec.template.spec.volumes = originalResource.spec?.template?.spec?.volumes;
+    mergedData.spec.template.spec.containers[0].volumeMounts =
+      originalResource.spec?.template?.spec?.containers?.[0]?.volumeMounts;
+  }
   return mergedData;
 };
 
