@@ -9,8 +9,6 @@ import {
 } from '../../../../components/create-vm-wizard/selectors/vm-settings';
 import { VMTemplateWrapper } from '../../../wrapper/vm/vm-template-wrapper';
 import { TEMPLATE_PARAM_VM_NAME, TEMPLATE_PARAM_VM_NAME_DESC } from '../../../../constants/vm';
-import { DataVolumeWrapper } from '../../../wrapper/vm/data-volume-wrapper';
-import { buildOwnerReference } from '../../../../utils';
 import { VMWrapper } from '../../../wrapper/vm/vm-wrapper';
 import { toShallowJS } from '../../../../utils/immutable';
 import { iGetRelevantTemplate } from '../../../../selectors/immutable/template/combined';
@@ -30,16 +28,16 @@ import { importV2VOvirtVm } from '../../v2v/import/import-ovirt';
 import { getOS } from '../../../../components/create-vm-wizard/selectors/combined';
 
 export const getInitializedVMTemplate = (params: CreateVMParams) => {
-  const { vmSettings, iCommonTemplates, iUserTemplates } = params;
+  const { vmSettings, iCommonTemplates, iUserTemplate } = params;
   const settings = asSimpleSettings(vmSettings);
 
   const temp = toShallowJS(
-    iGetRelevantTemplate(iUserTemplates, iCommonTemplates, {
-      userTemplateName: settings[VMSettingsField.USER_TEMPLATE],
-      workload: settings[VMSettingsField.WORKLOAD_PROFILE],
-      flavor: settings[VMSettingsField.FLAVOR],
-      os: settings[VMSettingsField.OPERATING_SYSTEM],
-    }),
+    iUserTemplate ||
+      iGetRelevantTemplate(iCommonTemplates, {
+        workload: settings[VMSettingsField.WORKLOAD_PROFILE],
+        flavor: settings[VMSettingsField.FLAVOR],
+        os: settings[VMSettingsField.OPERATING_SYSTEM],
+      }),
   );
 
   if (!temp) {
@@ -64,7 +62,7 @@ export const createVMTemplate = async (params: CreateVMParams) => {
     ...getOS({ osID: getFieldValue(vmSettings, VMSettingsField.OPERATING_SYSTEM), ...params }),
   };
 
-  const { template, storages } = getInitializedVMTemplate(params);
+  const { template } = getInitializedVMTemplate(params);
 
   const finalTemplate = new VMTemplateWrapper().init({
     name: combinedSimpleSettings[VMSettingsField.NAME],
@@ -80,20 +78,9 @@ export const createVMTemplate = async (params: CreateVMParams) => {
   });
 
   initializeCommonMetadata(combinedSimpleSettings, finalTemplate, template.asResource());
-  initializeCommonTemplateMetadata(finalTemplate, template.asResource());
+  initializeCommonTemplateMetadata(combinedSimpleSettings, finalTemplate, template.asResource());
 
-  const templateResult = await k8sWrapperCreate(finalTemplate);
-
-  if (templateResult && storages) {
-    for (const storage of storages.filter((s) => s.dataVolumeToCreate)) {
-      // eslint-disable-next-line no-await-in-loop
-      await k8sWrapperCreate(
-        new DataVolumeWrapper(storage.dataVolumeToCreate, true).addOwnerReferences(
-          buildOwnerReference(templateResult, { blockOwnerDeletion: true, controller: true }),
-        ),
-      );
-    }
-  }
+  await k8sWrapperCreate(finalTemplate);
   return getActualState();
 };
 
