@@ -5,6 +5,7 @@ import * as React from 'react';
 import { connect } from 'react-redux';
 import { Link } from 'react-router-dom';
 import { Button, TextInput } from '@patternfly/react-core';
+import { useTranslation } from 'react-i18next';
 
 import { withFallback } from '@console/shared/src/components/error/error-boundary';
 import { useDocumentListener, KEYBOARD_SHORTCUTS } from '@console/shared';
@@ -30,20 +31,23 @@ export const TextFilter = (props) => {
   const {
     label,
     className,
-    placeholder = `Filter ${label}...`,
+    placeholder,
     autoFocus = false,
     parentClassName,
+    ...otherInputProps
   } = props;
   const { ref } = useDocumentListener();
+  const { t } = useTranslation();
+  const placeholderText = placeholder ?? t('public~Filter {{label}}...', { label });
 
   return (
     <div className={classNames('has-feedback', parentClassName)}>
       <TextInput
-        {...props}
+        {...otherInputProps}
         className={classNames('co-text-filter', className)}
         data-test-id="item-filter"
-        aria-label={placeholder}
-        placeholder={placeholder}
+        aria-label={placeholderText}
+        placeholder={placeholderText}
         ref={ref}
         autoFocus={autoFocus}
         tabIndex={0}
@@ -58,7 +62,7 @@ export const TextFilter = (props) => {
 TextFilter.displayName = 'TextFilter';
 
 // TODO (jon) make this into "withListPageFilters" HOC
-/** @augments {React.PureComponent<{ListComponent: React.ComponentType<any>, kinds: string[], filters?:any, flatten?: function, data?: any[], rowFilters?: any[], hideToolbar?: boolean, hideLabelFilter?: boolean }>} */
+/** @augments {React.PureComponent<{ListComponent: React.ComponentType<any>, kinds: string[], filters?:any, flatten?: function, data?: any[], rowFilters?: any[], hideNameLabelFilters?: boolean, hideLabelFilter?: boolean, columnLayout?: ColumnLayout, name?:string }>} */
 export class ListPageWrapper_ extends React.PureComponent {
   render() {
     const {
@@ -67,18 +71,26 @@ export class ListPageWrapper_ extends React.PureComponent {
       reduxIDs,
       rowFilters,
       textFilter,
-      hideToolbar,
+      nameFilterPlaceholder,
+      labelFilterPlaceholder,
+      hideNameLabelFilters,
       hideLabelFilter,
+      columnLayout,
+      name,
     } = this.props;
     const data = flatten ? flatten(this.props.resources) : [];
     const Filter = (
       <FilterToolbar
         rowFilters={rowFilters}
         data={data}
+        nameFilterPlaceholder={nameFilterPlaceholder}
+        labelFilterPlaceholder={labelFilterPlaceholder}
         reduxIDs={reduxIDs}
         textFilter={textFilter}
-        hideToolbar={hideToolbar}
+        hideNameLabelFilters={hideNameLabelFilters}
         hideLabelFilter={hideLabelFilter}
+        columnLayout={columnLayout}
+        uniqueFilterName={name}
         {...this.props}
       />
     );
@@ -104,7 +116,7 @@ ListPageWrapper_.propTypes = {
   rowFilters: PropTypes.array,
   staticFilters: PropTypes.array,
   customData: PropTypes.any,
-  hideToolbar: PropTypes.bool,
+  hideNameLabelFilters: PropTypes.bool,
   hideLabelFilter: PropTypes.bool,
 };
 
@@ -199,7 +211,7 @@ export const FireMan_ = connect(null, { filterList })(
         if (createProps.to) {
           createLink = (
             <Link className="co-m-primary-action" {...createProps}>
-              <Button variant="primary" id="yaml-create">
+              <Button variant="primary" id="yaml-create" data-test="item-create">
                 {createButtonText}
               </Button>
             </Link>
@@ -210,6 +222,7 @@ export const FireMan_ = connect(null, { filterList })(
               <Dropdown
                 buttonClassName="pf-m-primary"
                 id="item-create"
+                dataTest="item-create"
                 menuClassName={classNames({ 'pf-m-align-right-on-md': title })}
                 title={createButtonText}
                 noSelection
@@ -221,7 +234,7 @@ export const FireMan_ = connect(null, { filterList })(
         } else {
           createLink = (
             <div className="co-m-primary-action">
-              <Button variant="primary" id="yaml-create" {...createProps}>
+              <Button variant="primary" id="yaml-create" data-test="item-create" {...createProps}>
                 {createButtonText}
               </Button>
             </div>
@@ -248,11 +261,7 @@ export const FireMan_ = connect(null, { filterList })(
             className={classNames({ 'co-m-nav-title--row': createLink })}
           >
             {createLink && (
-              <div
-                className={classNames('co-m-pane__createLink', {
-                  'co-m-pane__createLink--no-title': !title,
-                })}
-              >
+              <div className={classNames({ 'co-m-pane__createLink--no-title': !title })}>
                 {createLink}
               </div>
             )}
@@ -272,13 +281,10 @@ export const FireMan_ = connect(null, { filterList })(
     }
   },
 );
-
 FireMan_.displayName = 'FireMan';
-
 FireMan_.defaultProps = {
   textFilter: 'name',
 };
-
 FireMan_.propTypes = {
   canCreate: PropTypes.bool,
   createAccessReview: PropTypes.object,
@@ -307,7 +313,7 @@ FireMan_.propTypes = {
   title: PropTypes.string,
 };
 
-/** @type {React.SFC<{ListComponent: React.ComponentType<any>, kind: string, helpText?: any, namespace?: string, filterLabel?: string, textFilter?: string, title?: string, showTitle?: boolean, rowFilters?: any[], selector?: any, fieldSelector?: string, canCreate?: boolean, createButtonText?: string, createProps?: any, mock?: boolean, badge?: React.ReactNode, createHandler?: any, hideToolbar?: boolean, hideLabelFilter?: boolean, customData?: any} >} */
+/** @type {React.SFC<{ListComponent: React.ComponentType<any>, kind: string, helpText?: any, namespace?: string, filterLabel?: string, textFilter?: string, title?: string, showTitle?: boolean, rowFilters?: any[], selector?: any, fieldSelector?: string, canCreate?: boolean, createButtonText?: string, createProps?: any, mock?: boolean, badge?: React.ReactNode, createHandler?: any, hideNameLabelFilters?: boolean, hideLabelFilter?: boolean, columnLayout?: ColumnLayout, customData?: any, hideColumnManagement?: boolean, labelFilterPlaceholder?: string, nameFilterPlaceholder?: string, flatten?: any, name?: string } >} */
 export const ListPage = withFallback((props) => {
   const {
     autoFocus,
@@ -317,6 +323,8 @@ export const ListPage = withFallback((props) => {
     customData,
     fieldSelector,
     filterLabel,
+    labelFilterPlaceholder,
+    nameFilterPlaceholder,
     filters,
     helpText,
     kind,
@@ -332,13 +340,17 @@ export const ListPage = withFallback((props) => {
     textFilter,
     match,
     badge,
-    hideToolbar,
     hideLabelFilter,
+    hideNameLabelFilters,
+    hideColumnManagement,
+    columnLayout,
+    flatten = (_resources) => _.get(_resources, name || kind, {}).data,
   } = props;
+  const { t } = useTranslation();
   let { createProps } = props;
   const ko = kindObj(kind);
-  const { label, labelPlural, namespaced, plural } = ko;
-  const title = props.title || labelPlural;
+  const { label, labelKey, labelPlural, labelPluralKey, namespaced, plural } = ko;
+  const title = props.title || t(labelPluralKey) || labelPlural;
   const usedNamespace = !namespace && namespaced ? _.get(match, 'params.ns') : namespace;
 
   let href = usedNamespace
@@ -381,32 +393,38 @@ export const ListPage = withFallback((props) => {
       autoFocus={autoFocus}
       canCreate={canCreate}
       createAccessReview={createAccessReview}
-      createButtonText={createButtonText || `Create ${label}`}
+      createButtonText={
+        createButtonText || t('list-page~Create {{label}}', { label: t(labelKey) || label })
+      }
       createProps={createProps}
       customData={customData}
-      filterLabel={filterLabel || 'by name'}
-      flatten={(_resources) => _.get(_resources, name || kind, {}).data}
+      filterLabel={filterLabel || t('list-page~by name')}
+      nameFilterPlaceholder={nameFilterPlaceholder}
+      labelFilterPlaceholder={labelFilterPlaceholder}
+      flatten={flatten}
       helpText={helpText}
-      label={labelPlural}
+      label={t(labelPluralKey) || labelPlural}
       ListComponent={ListComponent}
       mock={mock}
       namespace={usedNamespace}
       resources={resources}
       rowFilters={rowFilters}
-      selectorFilterLabel="Filter by selector (app=nginx) ..."
+      selectorFilterLabel={t('list-page~Filter by selector (app=nginx) ...')}
       showTitle={showTitle}
       textFilter={textFilter}
       title={title}
       badge={badge}
-      hideToolbar={hideToolbar}
       hideLabelFilter={hideLabelFilter}
+      hideNameLabelFilters={hideNameLabelFilters}
+      hideColumnManagement={hideColumnManagement}
+      columnLayout={columnLayout}
     />
   );
 }, ErrorBoundaryFallback);
 
 ListPage.displayName = 'ListPage';
 
-/** @type {React.SFC<{canCreate?: boolean, createButtonText?: string, createProps?: any, createAccessReview?: Object, flatten?: Function, title?: string, label?: string, hideTextFilter?: boolean, showTitle?: boolean, helpText?: any, filterLabel?: string, textFilter?: string, rowFilters?: any[], resources: any[], ListComponent: React.ComponentType<any>, namespace?: string, customData?: any, badge?: React.ReactNode, hideToolbar?: boolean, hideLabelFilter?: boolean >} */
+/** @type {React.SFC<{canCreate?: boolean, createButtonText?: string, createProps?: any, createAccessReview?: Object, flatten?: Function, title?: string, label?: string, hideTextFilter?: boolean, showTitle?: boolean, helpText?: any, filterLabel?: string, textFilter?: string, rowFilters?: any[], resources: any[], ListComponent: React.ComponentType<any>, namespace?: string, customData?: any, badge?: React.ReactNode, hideNameLabelFilters?: boolean, hideLabelFilter?: boolean, columnLayout?: ColumnLayout, hideColumnManagement?: boolean, nameFilterPlaceholder?: string >} */
 export const MultiListPage = (props) => {
   const {
     autoFocus,
@@ -415,6 +433,8 @@ export const MultiListPage = (props) => {
     createButtonText,
     createProps,
     filterLabel,
+    nameFilterPlaceholder,
+    labelFilterPlaceholder,
     flatten,
     helpText,
     label,
@@ -428,10 +448,13 @@ export const MultiListPage = (props) => {
     title,
     customData,
     badge,
-    hideToolbar,
     hideLabelFilter,
+    hideNameLabelFilters,
+    hideColumnManagement,
+    columnLayout,
   } = props;
 
+  const { t } = useTranslation();
   const resources = _.map(props.resources, (r) => ({
     ...r,
     isList: r.isList !== undefined ? r.isList : true,
@@ -444,12 +467,12 @@ export const MultiListPage = (props) => {
       autoFocus={autoFocus}
       canCreate={canCreate}
       createAccessReview={createAccessReview}
-      createButtonText={createButtonText || 'Create'}
+      createButtonText={createButtonText || t('public~Create')}
       createProps={createProps}
-      filterLabel={filterLabel || 'by name'}
+      filterLabel={filterLabel || t('list-page~by name')}
       helpText={helpText}
       resources={mock ? [] : resources}
-      selectorFilterLabel="Filter by selector (app=nginx) ..."
+      selectorFilterLabel={t('list-page~Filter by selector (app=nginx) ...')}
       textFilter={textFilter}
       title={showTitle ? title : undefined}
       badge={badge}
@@ -464,8 +487,13 @@ export const MultiListPage = (props) => {
           rowFilters={rowFilters}
           staticFilters={staticFilters}
           customData={customData}
-          hideToolbar={hideToolbar}
           hideLabelFilter={hideLabelFilter}
+          hideNameLabelFilters={hideNameLabelFilters}
+          hideColumnManagement={hideColumnManagement}
+          columnLayout={columnLayout}
+          nameFilterPlaceholder={nameFilterPlaceholder}
+          labelFilterPlaceholder={labelFilterPlaceholder}
+          name={name}
         />
       </Firehose>
     </FireMan_>
