@@ -2,8 +2,9 @@ import * as _ from 'lodash-es';
 import * as React from 'react';
 import { Helmet } from 'react-helmet';
 import { Link } from 'react-router-dom';
-import { ActionGroup, Button } from '@patternfly/react-core';
-import { isCephProvisioner, isObjectSC } from '@console/shared/src/utils';
+import { ActionGroup, Button, Tooltip } from '@patternfly/react-core';
+import { OutlinedQuestionCircleIcon } from '@patternfly/react-icons';
+import { isCephProvisioner, isObjectSC, cephStorageProvisioners } from '@console/shared/src/utils';
 import { k8sCreate, K8sResourceKind, referenceFor } from '../../module/k8s';
 import { AsyncComponent, ButtonBar, RequestSizeInput, history, resourceObjPath } from '../utils';
 import { StorageClassDropdown } from '../utils/storage-class-dropdown';
@@ -16,10 +17,20 @@ import {
   provisionerAccessModeMapping,
   initialAccessModes,
   accessModeRadios,
+  volumeModeRadios,
   dropdownUnits,
   getAccessModeForProvisioner,
 } from './shared';
 
+const InfoToolTip = () => (
+  <Tooltip
+    position="bottom"
+    content={<div>Only filesystem volume mode is available for cephfs</div>}
+  >
+    <OutlinedQuestionCircleIcon />
+  </Tooltip>
+);
+
 const NameValueEditorComponent = (props) => (
   <AsyncComponent
     loader={() => import('../utils/name-value-editor').then((c) => c.NameValueEditor)}
@@ -35,6 +46,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
   const [storageClass, setStorageClass] = React.useState('');
   const [pvcName, setPvcName] = React.useState('');
   const [accessMode, setAccessMode] = React.useState('ReadWriteOnce');
+  const [volumeMode, setVolumeMode] = React.useState('Filesystem');
   const [requestSizeValue, setRequestSizeValue] = React.useState('');
   const [requestSizeUnit, setRequestSizeUnit] = React.useState('Gi');
   const [useSelector, setUseSelector] = React.useState(false);
@@ -68,6 +80,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
         },
         spec: {
           accessModes: [accessMode],
+          volumeMode,
           resources: {
             requests: {
               storage: `${requestSizeValue}${requestSizeUnit}`,
@@ -108,6 +121,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
     requestSizeUnit,
     useSelector,
     storageProvisioner,
+    volumeMode,
   ]);
 
   const handleNameValuePairs = ({ nameValuePairs: updatedNameValuePairs }) => {
@@ -131,6 +145,9 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
     setAllowedAccessModes(modes);
     setStorageClass(updatedStorageClass?.metadata?.name);
     setStorageProvisioner(provisioner);
+    if (storageProvisioner.includes(cephStorageProvisioners[1])) {
+      setVolumeMode('Filesystem');
+    }
   };
 
   const handleRequestSizeInputChange = (obj) => {
@@ -143,13 +160,17 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
   };
 
   const handlePvcName: React.ReactEventHandler<HTMLInputElement> = (event) => {
-    setPvcName(event.currentTarget.value);
+    setPvcName(event.currentTarget.value.trim());
   };
 
   const handleAccessMode: React.ReactEventHandler<HTMLInputElement> = (event) => {
     setAccessMode(event.currentTarget.value);
   };
 
+  const handleVolumeMode: React.ReactEventHandler<HTMLInputElement> = (event) => {
+    setVolumeMode(event.currentTarget.value);
+  };
+
   const onlyPvcSCs = React.useCallback((sc: StorageClass) => !isObjectSC(sc), []);
 
   return (
@@ -158,6 +179,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
         <StorageClassDropdown
           onChange={handleStorageClass}
           id="storageclass-dropdown"
+          data-test="storageclass-dropdown"
           describedBy="storageclass-dropdown-help"
           required={false}
           name="storageClass"
@@ -175,7 +197,9 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
           placeholder="my-storage-claim"
           aria-describedby="pvc-name-help"
           id="pvc-name"
+          data-test="pvc-name"
           name="pvcName"
+          value={pvcName}
           required
         />
         <p className="help-block" id="pvc-name-help">
@@ -224,6 +248,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
         dropdownUnits={dropdownUnits}
         describedBy="request-size-help"
         inputID="request-size-input"
+        testID="pvc-size"
       />
       <p className="help-block" id="request-size-help">
         Desired storage capacity
@@ -247,9 +272,30 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
           />
         )}
         <p className="help-block" id="label-selector-help">
-          Use label selectors to define how storage is created
+          PersistentVolume resources that match all label selectors will be considered for binding.
         </p>
       </div>
+      <label className="control-label" htmlFor="volume-mode">
+        Volume Mode
+      </label>
+      <div className="form-group">
+        {storageProvisioner.includes(cephStorageProvisioners[1]) ? (
+          <>
+            Filesystem <InfoToolTip />
+          </>
+        ) : (
+          volumeModeRadios.map((radio) => (
+            <RadioInput
+              {...radio}
+              key={radio.value}
+              onChange={handleVolumeMode}
+              inline
+              checked={radio.value === volumeMode}
+              name="volumeMode"
+            />
+          ))
+        )}
+      </div>
     </div>
   );
 };
@@ -298,7 +344,7 @@ export const CreatePVCPage: React.FC<CreatePVCPageProps> = (props) => {
         <CreatePVCForm onChange={setPvcObj} namespace={namespace} />
         <ButtonBar errorMessage={error} inProgress={inProgress}>
           <ActionGroup className="pf-c-form">
-            <Button id="save-changes" type="submit" variant="primary">
+            <Button id="save-changes" data-test="create-pvc" type="submit" variant="primary">
               Create
             </Button>
             <Button onClick={history.goBack} type="button" variant="secondary">
