@@ -14,7 +14,7 @@ export class StorageClassDropdownInner extends React.Component<
   readonly state: StorageClassDropdownInnerState = {
     items: {},
     name: this.props.name,
-    selectedKey: null,
+    selectedKey: this.props.selectedKey,
     title: <LoadingInline />,
     defaultClass: this.props.defaultClass,
   };
@@ -79,7 +79,7 @@ export class StorageClassDropdownInner extends React.Component<
       unorderedItems[''] = { kindLabel: '', name: noStorageClass };
     }
 
-    if (!this.props.loaded || !selectedKey) {
+    if (!this.props.loaded || !selectedKey || !unorderedItems[selectedKey || state.defaultClass]) {
       state.title = <span className="text-muted">Select storage class</span>;
     }
 
@@ -98,7 +98,9 @@ export class StorageClassDropdownInner extends React.Component<
 
   componentDidUpdate() {
     const { defaultClass, selectedKey } = this.state;
-    if (!selectedKey && defaultClass) {
+    if (selectedKey) {
+      this.onChange(selectedKey);
+    } else if (defaultClass) {
       this.onChange(defaultClass);
     }
   }
@@ -129,7 +131,7 @@ export class StorageClassDropdownInner extends React.Component<
   };
 
   render() {
-    const { id, loaded, describedBy } = this.props;
+    const { id, loaded, describedBy, noSelection } = this.props;
     const items = {};
     _.each(
       this.state.items,
@@ -169,11 +171,13 @@ export class StorageClassDropdownInner extends React.Component<
               title={this.state.title}
               onChange={this.onChange}
               id={id}
+              dataTest={this.props?.['data-test']}
+              noSelection={noSelection}
               menuClassName="dropdown-menu--text-wrap"
             />
             {describedBy && (
               <p className="help-block" id={describedBy}>
-                Storage class for the new claim.
+                Storage class for the new claim
               </p>
             )}
           </div>
@@ -239,4 +243,6 @@ export type StorageClassDropdownInnerProps = {
   required?: boolean;
   hideClassName?: string;
   filter?: (param) => boolean;
+  noSelection?: boolean;
+  selectedKey?: string;
 };
